==> viha-5.15.tar.gz: viha-5.15/tavara_tyyppi.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tavara_tyyppi";
$file = basename(__FILE__);

include "common.php";
include "tavara_tyyppi-ok.php";

echo "
<html>
<head>
 <title>VIHA - Kaluston tyyppikoodit</title>
</head>
" . body_bgcolor() . "
<h1>Kaluston tyyppikoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$tavara_tyyppi = get_txt('tavara_tyyppi');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tavara_tyyppi_add_ok($herja,$tavara_tyyppi);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET tavara_tyyppi = '$tavara_tyyppi',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = tavara_tyyppi_save_ok($herja,$id,$tavara_tyyppi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET tavara_tyyppi='$tavara_tyyppi',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot pivitetty.\n";
     loki($sql);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = tavara_tyyppi_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # confirm

if ($clear != '') {
  $id = '0';
  $tavara_tyyppi = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = tavara_tyyppi_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $tavara_tyyppi = $a['tavara_tyyppi'];
}

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Tavaran tyyppi:";
if ($readonly) {
  print "<td>$tavara_tyyppi\n";
} else {
  print "<td><input type=\"text\" name=\"tavara_tyyppi\" size=32 maxlength=32";
  print " value=\"$tavara_tyyppi\">\n";
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.tavara_tyyppi
FROM $table
ORDER BY $table.id
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Tyyppikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[tavara_tyyppi]";
    if (($id == "0") && ($a['id'] > 9)) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<p>Plop. Ei kaluston tyyppikooditietoja.";
 }

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tavara_tyyppi.php,v 1.12 2009/04/14 16:42:24 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tavara_tyyppi.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tavara_tyyppi";
$file = basename(__FILE__);

include "common.php";
include "tavara_tyyppi-ok.php";

echo "
<html>
<head>
 <title>VIHA - Kaluston tyyppikoodit</title>
</head>
" . body_bgcolor() . "
<h1>Kaluston tyyppikoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$tavara_tyyppi = get_txt('tavara_tyyppi');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tavara_tyyppi_add_ok($herja,$tavara_tyyppi);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET tavara_tyyppi = '$tavara_tyyppi',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = tavara_tyyppi_save_ok($herja,$id,$tavara_tyyppi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET tavara_tyyppi='$tavara_tyyppi',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot pivitetty.\n";
     loki($sql);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = tavara_tyyppi_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "CONFIRM";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # confirm

if ($clear != '') {
  $id = '0';
  $tavara_tyyppi = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = tavara_tyyppi_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $tavara_tyyppi = $a['tavara_tyyppi'];
}

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Tavaran tyyppi:";
if ($readonly) {
  print "<td>$tavara_tyyppi\n";
} else {
  print "<td><input type=\"text\" name=\"tavara_tyyppi\" size=32 maxlength=32";
  print " value=\"$tavara_tyyppi\">\n";
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.tavara_tyyppi
FROM $table
ORDER BY $table.id
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Tyyppikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[tavara_tyyppi]";
    if (($id == "0") && ($a['id'] > 9)) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<p>Plop. Ei kaluston tyyppikooditietoja.";
 }

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tavara_tyyppi.php,v 1.13 2009/09/29 16:09:15 riku Exp $ -->
